[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)


# inventree-rexel-plugin

This is a product import plugin for [InvenTree](https://inventree.org), which provides
support for importing product from rexel:

Error handling is very basic.

## Installation

The plugin is on pypi. Install this plugin using pip with the following command:

```
pip install inventree-rexel-plugin
```

## Configuration Options
### username

### password

## How it works
